#!/bin/sh
#\
exec wish "$0" "$@"

# Tcl script: B9Talker.tcl
#Version: 1.0 
# Author: mnorton
# Description:
#   Application is identical in functionality to Michael Joyce's 
#   Windows C application B9Talker,
#
#         http://www.b9robotbuildersclub.com 
#
#   This version is a Tcl script ported to Mac OS X using ActiveState 
#   Tcl scripting language and the QuickTimeTcl library.
#   Script works in both Windows and Mac OS X Wish Tcl environments.
#   Script should also work in Mac OS 9 Tcl environment but has not been
#   tested.
#
# Tested under: Mac OS X
# % info tclversion
#  8.4
#
# Mac OS X platforms:
# ActiveState Tcl w/ QuickTimeTcl 	http://www.activesate.com
#
# Windows platforms:
# ActiveState Tcl					http://www.activestate.com
# QuickTimeTcl 						http://quicktimetcl.sourceforge.net
#
#
# Installation (Mac OS X):
#   Download and install ActiveState Tcl for Mac OS X. The package 
#   installer will install Tcl, Wish and QuickTimeTcl.
#      --Note: The Tcl that ships with OS 10.3.9 and greater is now
#        a stripped down version and the full blown version must be 
#        downlaoded from ActiveState.
#
#   Install the script and the media resources in the same directory.
#   From your X-window terminal configure the B9Talker.tcl file to bin
#   executable.
#         chmod 777 B9Talker.tcl
#         ls -l B9Talker.tcl
#              -rwxrwxrwx  1 michaeln  admin  7782 26 Feb 20:05 B9Talker.tcl
#
# Execution (Mac OS X):
#    From UNIX X-windows,
#          ./B9Talker.tcl &
#
#    From Aqua GUI
#           App->Utilities->Wish  source B9Talker.tcl
#

########################################
# load libraries
#######################################
package require QuickTimeTcl 

# global Tcl frame to be used for Robot motor noise
frame .fMotor
set m ._wav

label .title -text "B9 Talker"

# default widget exit with ESC key
bind all <Escape> {exit}

########################################
# initialize script globals
#######################################

# set media file names 
set preLoad1file 		""
set preLoad2file 		""
set preLoad3file 		""
set pullPwrPckfile 		"ahhh.mp3"
set pluginPwrPckfile 	"whoturnedoutthelights.mp3"
set motorNoisefile 		"RobotNoise.wav"

#######################################
# Tcl procedures section
#######################################

# loadWavFile
# loads a wav file through a Tk dialog
#
# Arguments:
# none
# Returns:
#  wav file pathname
# 
proc loadWavFile {} {

	set wavFile ""
	
	set types {
 		{{Wav Files} {.wav}}
 		{{mp3 Files} {.mp3}}
 		}
 	set wavFile [tk_getOpenFile -filetypes $types]
 	#puts "debug(loadWavFile) wavFile <$wavFile>"
 return $wavFile

}

# playWavFile
#
# plays a pre-loaded file (.mp3 and .wav)
#
# Arguments:
# wavFile 		pathfile name
#
# Returns:
# none
#
proc playWavFile { wavFile } {

	if {$wavFile != ""} {
	destroy .fplayer
	
	frame .fplayer
	movie .fplayer.m -file $wavFile -controller 0
	.fplayer.m play
 		
	}

}

# playpullPwrPckfile
#
#   plays the robot animation dialog for 
#   removing the powerpack.
#
# trigger:
#   [Pull PwrPck] button
#
# Arguments:
# none
#
# Returns:
# none
#
proc playpullPwrPckfile {} {
	global pullPwrPckfile
	
	if {$pullPwrPckfile != ""} {
	destroy .fpullPwrPckplayer
	
	frame .fpullPwrPckplayer
	movie .fpullPwrPckplayer.m -file $pullPwrPckfile -controller 0
	.fpullPwrPckplayer.m play
 		
	}

}

# playpluginPwrPckfile
#
#  starts the robot power pack re-animation
#  dialog.
#
# trigger:
#   [Plug PwrPck] button
#
# Arguments:
# none
# Returns:
# none
#
proc playpluginPwrPckfile {} {
	global pluginPwrPckfile
	
	if {$pluginPwrPckfile != ""} {
	destroy .fpluginPwrPckplayer
	
	frame .fpluginPwrPckplayer
	movie .fpluginPwrPckplayer.m -file $pluginPwrPckfile -controller 0
	.fpluginPwrPckplayer.m play
 		
	}

}

# playMediaFile
#
#  loads an .mp3 or .wav file and plays it.
#
# trigger:
#  [Play Wav File] button
#
# Arguments:
# none
# Returns:
# none
#
proc playMediaFile {} {

	set mediafile ""
	
  	set mediafile [loadWavFile]
  	if {$mediafile != ""} {
  		playWavFile $mediafile 
  	}

}
	
# checkMediaFileExists
#
# checks to see if a media file (.mp3 or .wav file exists)/
# opens a dialog window to locate file if not found in 
# local directory.
#
# Arguments:
# none
#
# Returns:
# none
#
proc checkMediaFileExists { filename } {

	if {[file exists $filename]  == 0} {
		set filepath ""
	
		set types {
 			{{Wav Files} {.wav}}
 			{{mp3 Files} {.mp3}}
 		}
 		set filepath [tk_getOpenFile -title "Where is $filename ?" -filetypes $types]
   		return $filepath
   	}
	return $filename
}

#######################################
# script main section
#######################################

# initialize the Tk widget frames
#
#               +------------------------------------------------------+
#   .fB9Talker  |  [Power Up] [Power Off] [Pull PwrPck] [Plug PwrPck]  |
#               +------------------------------------------------------+
#   .fPreLoad1  |               [PreLoad1] [Play PreLoad1]             |
#               +------------------------------------------------------+
#   .fPreLoad2  |               [PreLoad2] [Play PreLoad2]             |
#               +------------------------------------------------------+
#   .fPreLoad3  |               [PreLoad3] [Play PreLoad2]             |
#               +------------------------------------------------------+
#   .f          |                [Play Wav] [Exit]                     |
#               +------------------------------------------------------+
#
frame .fB9Talker
frame .fPreLoad1
frame .fPreLoad2
frame .fPreLoad3
frame .f



# verify the existence of files. 
# when run from the Aqua gui the native dir is /usr/bin.
# Loading the files is required.
set motorNoisefile [checkMediaFileExists $motorNoisefile]
set pullPwrPckfile [checkMediaFileExists $pullPwrPckfile]
set pluginPwrPckfile [checkMediaFileExists $pluginPwrPckfile]

# create the buttons for frame .B9talker
#               +------------------------------------------------------+
#   .fB9Talker  |  [Power Up] [Power Off] [Pull PwrPck] [Plug PwrPck]  |
#               +------------------------------------------------------+
#

# intialize the robot motor noise
movie .m -file  $motorNoisefile -loopstate 1
pack .m

# initalize the Tcl frame
#button .fB9Talker.powerUp -text "Power Up" -command { .m play }
#button .fB9Talker.powerOff -text "Power Off" -command { .m stop }
button .fB9Talker.pullPP -text "Pull PwrPck" -command playpullPwrPckfile
button .fB9Talker.plugPP -text "Plug PwrPck" -command  playpluginPwrPckfile 
#pack .fB9Talker.powerUp -side left 
#pack .fB9Talker.powerOff -side left
pack .fB9Talker.pullPP -side left
pack .fB9Talker.plugPP -side left


# create the buttons for frame .fPreLoad1
#               +------------------------------------------------------+
#   .fPreLoad1  |               [PreLoad1] [Play PreLoad1]             |
#               +------------------------------------------------------+
#
button .fPreLoad1.preLoad1 -text "PreLoad1" -command { set preLoad1file [loadWavFile]}
button .fPreLoad1.playPreLoad1 -text "Play PreLoad1" -command {playWavFile $preLoad1file}
pack .fPreLoad1.preLoad1 -side left
pack .fPreLoad1.playPreLoad1 -side left

# create the buttons for frame .fPreLoad2
#               +------------------------------------------------------+
#   .fPreLoad1  |               [PreLoad2] [Play PreLoad2]             |
#               +------------------------------------------------------+
#
button .fPreLoad2.preLoad2 -text "PreLoad2" -command { set preLoad2file [loadWavFile]}
button .fPreLoad2.playPreLoad2 -text "Play PreLoad2" -command {playWavFile $preLoad2file}
pack .fPreLoad2.preLoad2 -side left
pack .fPreLoad2.playPreLoad2 -side left

# create the buttons for frame .fPreLoad3
#               +------------------------------------------------------+
#   .fPreLoad1  |               [PreLoad3] [Play PreLoad3]             |
#               +------------------------------------------------------+
#
button .fPreLoad3.preLoad3 -text "PreLoad3" -command { set preLoad3file [loadWavFile]}
button .fPreLoad3.playPreLoad3 -text "Play PreLoad3" -command {playWavFile $preLoad3file}
pack .fPreLoad3.preLoad3 -side left
pack .fPreLoad3.playPreLoad3 -side left


# create the buttons for frame .f
#               +------------------------------------------------------+
#   .f          |                [Play Wav] [Exit]                     |
#               +------------------------------------------------------+
#
button .f.playWav -text "Play Media file" -command playMediaFile
button .f.exit -text "Exit" -command exit 
pack .f.playWav -side left
pack .f.exit -side left
 
# pack the widget buttons into the frames
pack .fB9Talker -side top
pack .fPreLoad1 -side top 
pack .fPreLoad2 -side top
pack .fPreLoad3 -side top
pack .f -side top


